==> hyades.source_1.0.4.1.zip: org/eclipse/hyades/loaders/common/ExecutionConstants.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.loaders.common;

/**
 * @author amathur
 */
public class ExecutionConstants {

	protected static final int EVENT_ID_int = 3355;
	protected static final int EVENT_INVOCATION_REASON_int = -934964668;
	protected static final int EVENT_INVOCATION_STATUS_int = -892481550;
	protected static final int EVENT_MESSAGE_SEVERITY_int = 1478300413;
	protected static final int EVENT_OWNERID_int = -1054729426;
	protected static final int EVENT_TEXT_int = 3556653;
	protected static final int EVENT_TIMESTAMP_int = 55126294;
	protected static final int EVENT_TYPED_TYPE_int = 3575610;
	protected static final int EVENT_VERDICT_REASON_int = -934964668;
	protected static final int EVENT_VERDICT_VERDICT_int = 351160793;
	protected static final int executionEvent_int = 1798599298;
	protected static final int invocationEvent_int = -857349142;
	protected static final int messageEvent_int = -1310036269;
	protected static final int typedEvent_int = -979313584;
	protected static final int verdictEvent_int = -672761791;
}

==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/loaders/common/ExecutionConstants.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.loaders.common;

/**
 * @author amathur
 */
public class ExecutionConstants {

	protected static final int EVENT_ID_int = 3355;
	protected static final int EVENT_INVOCATION_REASON_int = -934964668;
	protected static final int EVENT_INVOCATION_STATUS_int = -892481550;
	protected static final int EVENT_LOOP_ASYCHRONOUS_int = -1368209400;
	protected static final int EVENT_LOOP_ITERATIONS_int = -1751585482;
	protected static final int EVENT_MESSAGE_SEVERITY_int = 1478300413;
	protected static final int EVENT_OWNERID_int = -1054729426;
	protected static final int EVENT_PARENTID_int = 1175162725;
	protected static final int EVENT_TEXT_int = 3556653;
	protected static final int EVENT_TIMESTAMP_int = 55126294;
	protected static final int EVENT_TYPED_TYPE_int = 3575610;
	protected static final int EVENT_VERDICT_CAUSEDBY_int = 91997906;
	protected static final int EVENT_VERDICT_REASON_int = -934964668;
	protected static final int EVENT_VERDICT_VERDICT_int = 351160793;
	protected static final int executionEvent_int = 1798599298;
	protected static final int invocationEvent_int = -857349142;
	protected static final int loopEvent_int = 1249329750;
	protected static final int messageEvent_int = -1310036269;
	protected static final int typedEvent_int = -979313584;
	protected static final int verdictEvent_int = -672761791;
}
